@@ -15,6 +15,9 @@ class Identifier:
     pv_power_a: str = "pv_power_a"
     pv_power_b: str = "pv_power_b"
     pv_power_c: str = "pv_power_c"
+    pv_total_power_a: str = "pv_total_power_a"
+    pv_total_power_b: str = "pv_total_power_b"
+    pv_total_power_c: str = "pv_total_power_c"
     pv_voltage_a: str = "pv_voltage_a"
     pv_voltage_b: str = "pv_voltage_b"
     pv_voltage_c: str = "pv_voltage_c"
@@ -122,6 +125,7 @@ class Identifier:
     energy_meter: str = "energy_meter"
     operating_status_genereal: str = "operating_status_general"
     operating_status: str = "operating_status"
+    operating_mode: str = "operating_mode"
     inverter_condition: str = "inverter_condition"
     inverter_system_init: str = "inverter_system_init"
     grid_connection_status: str = "grid_connection_status"
@@ -133,6 +137,8 @@ class Identifier:
     status: str = "status"
     active_power_limitation: str = "active_power_limitation"
     power_limit_via_io: str = "power_limit_via_io"
+    charging_station_total_absorbed: str = "charging_station_total_absorbed"
+    charging_station_power_absorbed: str = "charging_station_power_absorbed"
 
     operating_mode_plant_control: str = "operating_mode_plant_control"
     power_setpoint_plant_control: str = "power_setpoint_plant_control"
@@ -142,6 +148,7 @@ class Identifier:
         "charge_current_limit"  # channel="Parameter.Inverter.AcALim"
     )
     power_limit_in: str = "power_limit_in"  # channel="Parameter.Inverter.WMaxIn"
+    active_power_limitation_gcp = "active_power_limitation_gcp"
 
 
 # Data-Source:
@@ -168,8 +175,8 @@ SMATagList: Dict[int, str] = {
     336: "Contact the manufacturer",
     337: "Contact the installer",
     338: "Invalid",
-    349: "Energy Meter 2",
-    372: "Sunny Home Manager 2",
+    #    349: "Energy Meter 2",
+    #   372: "Sunny Home Manager 2",
     381: "Stop",
     402: "Phases L1 and L2 (phsAB)",
     403: "Phases L1 and L3 (phsAC)",
@@ -616,12 +623,17 @@ SMATagList: Dict[int, str] = {
     9489: "SUNNY TRIPOWER X 20",
     9491: "SUNNY TRIPOWER X 15",
     9492: "SUNNY TRIPOWER X 12",
+    9483: "EVC7.4-1AC-10",
     9484: "EVC22-3AC-10",
     19048: "STP5.0SE (SUNNY TRIPOWER 5.0 SE)",
     19049: "STP6.0SE (SUNNY TRIPOWER 6.0 SE)",
     19050: "STP8.0SE (SUNNY TRIPOWER 8.0 SE)",
     19051: "STP10.0SE (SUNNY TRIPOWER 10.0 SE)",
+    19085: "Sunny Boy Smart Energy 6.0",
+    19128: "Sunny Boy Smart Energy 3.6",
+    19129: "Sunny Boy Smart Energy 4.0",
     19130: "Sunny Boy Smart Energy 5.0",
+    19143: "EVC22-3AC-20",
     200111: "Not connected",  # EV-Charger
     200112: "Sleep Mode",  # EV-Charger
     200113: "Active Mode",  # EV-Charger
