@@ -5,6 +5,8 @@ Definition for all enneoxOS senosrs
 from .const import Identifier, SMATagList
 from .sensor import Sensor
 
+DEFAULT_TIMEOUT = 8
+
 """ The profiles are necessary because the devices generally
     return a significantly lower number of measured values without sunlight. """
 ennexosSensorProfiles: list[tuple[list[int], list[str]]] = [
@@ -100,9 +102,8 @@ ennexosSensorProfiles: list[tuple[list[int], list[str]]] = [
             "Inverter.WMax",
         ],
     ),
-    # Charger
     (
-        [9484],
+        [9483, 9484],  # Charger
         [
             "ChaSess.WhIn",
             "Chrg.ModSw",
@@ -133,10 +134,10 @@ ennexosSensorProfiles: list[tuple[list[int], list[str]]] = [
             "Wl.SoftAcsConnStt",
         ],
     ),
-    # Sunny Boy Smart Energy 5.0
     (
-        [19130],
+        [19085, 19128, 19129, 19130],  # Sunny Boy Smart Energy 3.6, 4.0, 5.0, 6.0
         [
+            "Operation.Bat.Health.1",
             "Coolsys.Inverter.TmpVal.1",
             "DcMs.Amp.1",
             "DcMs.Amp.2",
@@ -212,15 +213,18 @@ ennexosSensorProfiles: list[tuple[list[int], list[str]]] = [
             "Wl.SigPwr",
             "Wl.SoftAcsConnStt",
             "Bat.Amp.1",
+            "Bat.ChaStt",
             "Bat.ChaSttArr.1",
             "Bat.Diag.VolMax.1",
             "Bat.OpTms.1",
             "Bat.Vol.1",
             "BatChrg.BatChrg",
             "BatChrg.BatChrgArr.1",
+            "BatChrg.CurBatCha",
             "BatChrg.CurBatChaArr.1",
             "BatDsch.BatDsch",
             "BatDsch.BatDschArr.1",
+            "BatDsch.CurBatDsch",
             "BatDsch.CurBatDschArr.1",
             "DcMs.TotDcEnCntWh.1",
             "DcMs.TotDcEnCntWh.2",
@@ -277,11 +281,11 @@ ennexosSensorProfiles: list[tuple[list[int], list[str]]] = [
             "Metering.GridMs.TotWhIn.Bat",
             "Metering.GridMs.TotWhOut.Bat",
             "Inverter.WMax",
+            "Bat.TmpVal.1",
         ],
     ),
-    # Data Manager EDMM-10
     (
-        [9397],
+        [9397],  # Data Manager EDMM-10
         [
             "Operation.Health",
             "DevUpd.IsOn",
@@ -319,9 +323,8 @@ ennexosSensorProfiles: list[tuple[list[int], list[str]]] = [
             "WebConn.SwRev",
         ],
     ),
-    # Energy Meter
     (
-        [9307],
+        [9307],  # Energy Meter
         [
             "Metering.GridMs.TotWIn",
             "Metering.GridMs.TotWhIn",
@@ -347,9 +350,582 @@ ennexosSensorProfiles: list[tuple[list[int], list[str]]] = [
             "Metering.GridMs.VAr.phsC",
         ],
     ),
-    # Fake Number for Plants
     (
-        [-47114711],
+        [9054],  # SMC 7000TL via DataManager
+        [
+            "Coolsys.Inverter.TmpVal",
+            "DcMs.Amp.1",
+            "DcMs.Vol.1",
+            "DcMs.Watt.1",
+            "GridMs.A.phsA",
+            "GridMs.A.phsB",
+            "GridMs.A.phsC",
+            "GridMs.Hz",
+            "GridMs.PhV.phsA",
+            "GridMs.PhV.phsB",
+            "GridMs.PhV.phsC",
+            "GridMs.TotW",
+            "GridMs.TotW.Pv",
+            "Isolation.FltA",
+            "Isolation.LeakRis",
+            "Metering.TotFeedTms",
+            "Metering.TotOpTms",
+            "Metering.TotWhOut.Pv",
+            "Operation.GriSwCnt",
+            "Operation.Health",
+            "Setpoint.PlantControl.Inverter.FstStop",
+            "Setpoint.PlantControl.Inverter.WModCfg.WCtlComCfg.WNom",
+            "GridGuard.Cntry.FrqCtl.hLim",
+            "Metering.TotkWhOutSet",
+            "GridGuard.Cntry.FrqCtl.Max",
+            "Nameplate.CmpMain.SwRev",
+            "Metering.TotFeedTmhSet",
+            "GridGuard.Cntry.VolCtl.Rpro",
+            "Nameplate.CmpCom.SwRev",
+            "GridGuard.Cntry.Aid.PerAid.Ampl",
+            "GridGuard.Cntry.VRefOfs",
+            "Inverter.OffGri.HzdLim",
+            "Inverter.StopTms",
+            "DcCfg.StrTms",
+            "GridGuard.Cntry.FrqCtl.hLimTmms",
+            "Inverter.OffGri.HzdStr",
+            "GridGuard.Cntry.Aid.PerAid.Hz",
+            "GridGuard.Cntry.VolCtl.lLim",
+            "Nameplate.Model",
+            "GridGuard.CntrySet",
+            "Inverter.WLim",
+            "Coolsys.FanTst",
+            "Operation.OpMod",
+            "GridGuard.Cntry.VolCtl.llLimTmms",
+            "GridGuard.Cntry.VolCtl.hhLim",
+            "GridGuard.Cntry.VolCtl.llLim",
+            "Nameplate.Location",
+            "GridGuard.Cntry.VolCtl.hhLimTmms",
+            "GridGuard.Cntry.FrqCtl.MaxTmms",
+            "GridGuard.Cntry.VolCtl.hLimTmms",
+            "GridGuard.Cntry.VolCtl.lLimTmms",
+            "Inverter.OutPhs",
+            "Inverter.WMax",
+            "GridGuard.Cntry.FrqCtl.Min",
+            "Nameplate.MainModel",
+            "DcCfg.StrVol",
+            "GridGuard.Cntry.FrqCtl.lLim",
+            "GridGuard.Cntry.FrqCtl.lLimTmms",
+            "Nameplate.Vendor",
+            "DcCfg.ConstVolCtl.Vset",
+            "GridGuard.Cntry.FrqCtl.ChgMax",
+            "GridGuard.Cntry.VolCtl.hLim",
+            "GridGuard.Cntry.Aid.AngFact",
+            "GridGuard.Cntry.GridGuardRev",
+            "GridGuard.Cntry.FrqCtl.MinTmms",
+            "Operation.PwrBal.OpMod",
+            "Operation.ValRsIstl",
+            "Nameplate.SerNum",
+            "GridGuard.Cntry.AMaxOfs",
+            "GridGuard.Cntry.LeakRisMin",
+        ],
+    ),
+    (
+        [8001],  # SMC 9000TL-10 via DataManager
+        [
+            "Coolsys.Inverter.TmpVal",
+            "DcMs.Amp.1",
+            "DcMs.Vol.1",
+            "DcMs.Watt.1",
+            "DcMs.Amp.2",
+            "DcMs.Vol.2",
+            "DcMs.Watt.2",
+            "GridGuard.Cntry",
+            "GridMs.A.phsA",
+            "GridMs.A.phsB",
+            "GridMs.A.phsC",
+            "GridMs.Hz",
+            "GridMs.PhV.phsA",
+            "GridMs.PhV.phsB",
+            "GridMs.PhV.phsC",
+            "GridMs.TotVA",
+            "GridMs.TotVAr",
+            "GridMs.TotVAr.Pv",
+            "GridMs.TotW",
+            "GridMs.TotW.Pv",
+            "GridMs.W.phsA",
+            "GridMs.W.phsB",
+            "GridMs.W.phsC",
+            "Isolation.FltA",
+            "Isolation.LeakRis",
+            "Metering.TotFeedTms",
+            "Metering.TotOpTms",
+            "Metering.TotWhOut.Pv",
+            "Operation.DrtStt",
+            "Operation.Evt.EvtNo",
+            "Operation.Evt.EvtNoShrt",
+            "Operation.Evt.Prio",
+            "Operation.EvtCntIstl",
+            "Operation.EvtCntUsr",
+            "Operation.GriSwCnt",
+            "Operation.GriSwStt",
+            "Operation.Health",
+            "Operation.RmgTms",
+            "Setpoint.PlantControl.Inverter.FstStop",
+            "Setpoint.PlantControl.Inverter.WModCfg.WCtlComCfg.WNom",
+            "Nameplate.CmpMdul.Rev",
+            "Metering.TotkWhOutSet",
+            "DcCfg.VolLim[]",
+            "Metering.TotFeedTmhSet",
+            "Nameplate.CmpMain.SwRev",
+            "GridGuard.Cntry.VolCtl.Max",
+            "Nameplate.CmpMain.HwRev",
+            "GridGuard.Cntry.VolCtl.Rpro",
+            "Nameplate.CmpRS485.HwRev",
+            "Nameplate.CmpCom.Rev",
+            "DcCfg.MPPShdw.IsOn",
+            "Inverter.OffGri.HzdLim",
+            "GridGuard.Cntry.FrqCtl.hLimTmms",
+            "DcCfg.StrTms[]",
+            "Bt.BtPwr",
+            "Nameplate.Model",
+            "GridGuard.CntrySet",
+            "Inverter.WLim",
+            "Coolsys.FanTst",
+            "Operation.OpMod",
+            "GridGuard.Cntry.PEOpnMon",
+            "Nameplate.CmpRS485.SwRev",
+            "GridGuard.Cntry.AMaxOfsTmms",
+            "GridGuard.Cntry.VolCtl.hhLim",
+            "Nameplate.CmpFltASw.Rev",
+            "Inverter.WMaxTm",
+            "GridGuard.Cntry.VolCtl.llLim",
+            "Nameplate.Location",
+            "GridGuard.Cntry.VolCtl.hLimTmms",
+            "Nameplate.CmpSigProc.Rev",
+            "GridGuard.Cntry.VolCtl.lLimTmms",
+            "Inverter.OutPhs",
+            "Nameplate.MainModel",
+            "Nameplate.PkgRev",
+            "GridGuard.Cntry.FrqCtl.lLimTmms",
+            "Nameplate.CmpMdul.SwRev",
+            "Nameplate.CmpFltASw.HwRev",
+            "GridGuard.Cntry.Aid.AngFact",
+            "DcCfg.MPPShdw.CycTms",
+            "Nameplate.CmpRS485.Rev",
+            "GridGuard.Cntry",
+            "Operation.ValRsIstl",
+            "Nameplate.SerNum",
+            "GridGuard.Cntry.AMaxOfs",
+            "GridGuard.Cntry.LeakRisMin",
+            "Nameplate.CmpBt.SwRev",
+            "GridGuard.Cntry.GriFltTms",
+            "Metering.TotOpTmhSet",
+            "GridGuard.Cntry.FrqCtl.hLim",
+            "GridGuard.Cntry.FrqCtl.Max",
+            "GridGuard.Cntry.GriStrTms",
+            "Nameplate.CmpCom.SwRev",
+            "GridGuard.Cntry.VolCtl.MaxTmms",
+            "Inverter.StopTms",
+            "Nameplate.CmpCom.HwRev",
+            "Inverter.OffGri.HzdStr",
+            "Nameplate.CmpMain.Rev",
+            "GridGuard.Cntry.VolCtl.lLim",
+            "Nameplate.CmpBt.Rev",
+            "GridGuard.Cntry.GriFltReConTms",
+            "GridGuard.Cntry.VolCtl.llLimTmms",
+            "GridGuard.Cntry.VolCtl.hhLimTmms",
+            "GridGuard.Cntry.FrqCtl.MaxTmms",
+            "Nameplate.CmpDisp.Rev",
+            "Nameplate.CmpDisp.SwRev",
+            "Nameplate.CmpMdul.HwRev",
+            "Nameplate.CmpSigProc.SwRev",
+            "Inverter.WMax",
+            "GridGuard.Cntry.FrqCtl.Min",
+            "DcCfg.StrVol[]",
+            "GridGuard.Cntry.FrqCtl.lLim",
+            "Nameplate.ComRev",
+            "Nameplate.CmpDisp.SerNum",
+            "Nameplate.Vendor",
+            "DcCfg.ConstVolCtl.Vset[]",
+            "GridGuard.Cntry.VolCtl.hLim",
+            "Nameplate.CmpFltASw.SwRev",
+            "GridGuard.Cntry.GriFltMonTms",
+            "GridGuard.Cntry.FrqCtl.MinTmms",
+            "Operation.LodFnc",
+        ],
+    ),
+    (
+        [9056],  # "SMC 9000TL-10
+        [
+            "Coolsys.Cab.TmpValIstl",
+            "Coolsys.Cab.TmpValMaxIstl",
+            "Coolsys.Inverter.TmpVal",
+            "DcMs.Amp.1",
+            "DcMs.Vol.1",
+            "DcMs.Watt.1",
+            "DcMs.Amp.2",
+            "DcMs.Vol.2",
+            "DcMs.Watt.2",
+            "GridMs.A.phsA",
+            "GridMs.A.phsB",
+            "GridMs.A.phsC",
+            "GridMs.Hz",
+            "GridMs.PhV.phsA",
+            "GridMs.PhV.phsB",
+            "GridMs.PhV.phsC",
+            "GridMs.TotW",
+            "GridMs.TotW.Pv",
+            "Isolation.FltA",
+            "Isolation.LeakRis",
+            "Metering.TotFeedTms",
+            "Metering.TotOpTms",
+            "Metering.TotWhOut.Pv",
+            "Operation.GriSwCnt",
+            "Operation.Health",
+            "Setpoint.PlantControl.Inverter.FstStop",
+            "Setpoint.PlantControl.Inverter.WModCfg.WCtlComCfg.WNom",
+            "GridGuard.Cntry.FrqCtl.hLim",
+            "GridGuard.Cntry.Aid.HzMon.HzLim",
+            "Metering.TotkWhOutSet",
+            "Nameplate.CmpMain.SwRev",
+            "Metering.TotFeedTmhSet",
+            "GridGuard.Cntry.VolCtl.Rpro",
+            "Nameplate.CmpCom.SwRev",
+            "GridGuard.Cntry.Aid.PerAid.Ampl",
+            "GridGuard.Cntry.VRefOfs",
+            "Inverter.OffGri.HzdLim",
+            "Inverter.StopTms",
+            "DcCfg.StrTms",
+            "Inverter.OffGri.HzdStr",
+            "GridGuard.Cntry.Aid.PerAid.Hz",
+            "GridGuard.Cntry.VolCtl.lLim",
+            "Nameplate.Model",
+            "GridGuard.CntrySet",
+            "Inverter.WLim",
+            "Coolsys.FanTst",
+            "Operation.OpMod",
+            "GridGuard.Cntry.VolCtl.hhLim",
+            "GridGuard.Cntry.VolCtl.llLim",
+            "Nameplate.Location",
+            "Inverter.OutPhs",
+            "Inverter.WMax",
+            "Nameplate.MainModel",
+            "DcCfg.StrVol",
+            "GridGuard.Cntry.FrqCtl.lLim",
+            "Nameplate.Vendor",
+            "DcCfg.ConstVolCtl.Vset",
+            "GridGuard.Cntry.FrqCtl.ChgMax",
+            "GridGuard.Cntry.VolCtl.hLim",
+            "GridGuard.Cntry.Aid.AngFact",
+            "GridGuard.Cntry.GridGuardRev",
+            "Operation.PwrBal.OpMod",
+            "Operation.ValRsIstl",
+            "Nameplate.SerNum",
+            "GridGuard.Cntry.AMaxOfs",
+            "GridGuard.Cntry.LeakRisMin",
+        ],
+    ),
+    (
+        [19047],  # STP 110-60
+        [
+            "DcMs.Amp.1",
+            "DcMs.Vol.1",
+            "DcMs.Watt.1",
+            "DcMs.Amp.2",
+            "DcMs.Vol.2",
+            "DcMs.Watt.2",
+            "GridMs.A.phsA",
+            "GridMs.A.phsB",
+            "GridMs.A.phsC",
+            "GridMs.Hz",
+            "GridMs.PhV.phsA",
+            "GridMs.PhV.phsA2B",
+            "GridMs.PhV.phsB",
+            "GridMs.PhV.phsB2C",
+            "GridMs.PhV.phsC",
+            "GridMs.PhV.phsC2A",
+            "GridMs.TotA",
+            "GridMs.TotPFEEI",
+            "GridMs.TotVA",
+            "GridMs.TotVAr",
+            "GridMs.TotVAr.Pv",
+            "GridMs.TotW",
+            "GridMs.TotW.Pv",
+            "Metering.TotWhOut",
+            "Metering.TotWhOut.Pv",
+            "Operation.Evt.EvtNo",
+            "Operation.Evt.Msg",
+            "Operation.FailCode",
+            "Operation.GriSwStt",
+            "Operation.Health",
+            "Operation.OpStt",
+            "Operation.PvGriConn",
+            "Nameplate.Model",
+            "Inverter.WLim",
+            "Nameplate.Location",
+            "Inverter.VArMaxQ1Rtg",
+            "Nameplate.MainModel",
+            "Nameplate.PkgRev",
+            "Bat.CapacRtgWh",
+            "Nameplate.SerNum",
+            "Nameplate.ModelStr",
+            "Spdwr.ActlIp",
+            "Nameplate.ARtg",
+            "Inverter.VArMaxQ4Rtg",
+            "Bat.CapacRtg",
+            "Nameplate.VendorStr",
+        ],
+    ),
+    (
+        [358],  # SB 4000TL-20
+        [
+            "DcMs.Amp.1",
+            "DcMs.Vol.1",
+            "DcMs.Watt.1",
+            "DcMs.Amp.2",
+            "DcMs.Vol.2",
+            "DcMs.Watt.2",
+            "Coolsys.Inverter.TmpVal",
+            "GridGuard.Cntry",
+            "GridMs.A.phsA",
+            "GridMs.A.phsB",
+            "GridMs.A.phsC",
+            "GridMs.Hz",
+            "GridMs.PhV.phsA",
+            "GridMs.PhV.phsB",
+            "GridMs.PhV.phsC",
+            "GridMs.TotVA",
+            "GridMs.TotVAr",
+            "GridMs.TotVAr.Pv",
+            "GridMs.TotW",
+            "GridMs.TotW.Pv",
+            "GridMs.W.phsA",
+            "GridMs.W.phsB",
+            "GridMs.W.phsC",
+            "Isolation.FltA",
+            "Isolation.LeakRis",
+            "Metering.TotFeedTms",
+            "Metering.TotOpTms",
+            "Metering.TotWhOut.Pv",
+            "Operation.DrtStt",
+            "Operation.Evt.EvtNo",
+            "Operation.Evt.EvtNoShrt",
+            "Operation.Evt.Prio",
+            "Operation.EvtCntIstl",
+            "Operation.EvtCntUsr",
+            "Operation.GriSwCnt",
+            "Operation.GriSwStt",
+            "Operation.Health",
+            "Operation.RmgTms",
+            "Setpoint.PlantControl.Inverter.FstStop",
+            "Setpoint.PlantControl.Inverter.WModCfg.WCtlComCfg.WNom",
+            "Nameplate.CmpMdul.Rev",
+            "Metering.TotkWhOutSet",
+            "DcCfg.VolLim[]",
+            "Metering.TotFeedTmhSet",
+            "Nameplate.CmpMain.SwRev",
+            "GridGuard.Cntry.VolCtl.Max",
+            "Nameplate.CmpMain.HwRev",
+            "GridGuard.Cntry.VolCtl.Rpro",
+            "Nameplate.CmpRS485.HwRev",
+            "Nameplate.CmpCom.Rev",
+            "DcCfg.MPPShdw.IsOn",
+            "Inverter.OffGri.HzdLim",
+            "GridGuard.Cntry.FrqCtl.hLimTmms",
+            "DcCfg.StrTms[]",
+            "Bt.BtPwr",
+            "Nameplate.Model",
+            "GridGuard.CntrySet",
+            "Inverter.WLim",
+            "Coolsys.FanTst",
+            "Operation.OpMod",
+            "GridGuard.Cntry.PEOpnMon",
+            "Nameplate.CmpRS485.SwRev",
+            "GridGuard.Cntry.AMaxOfsTmms",
+            "GridGuard.Cntry.VolCtl.hhLim",
+            "Nameplate.CmpFltASw.Rev",
+            "Inverter.WMaxTm",
+            "GridGuard.Cntry.VolCtl.llLim",
+            "Nameplate.Location",
+            "GridGuard.Cntry.VolCtl.hLimTmms",
+            "Nameplate.CmpSigProc.Rev",
+            "GridGuard.Cntry.VolCtl.lLimTmms",
+            "Inverter.OutPhs",
+            "Nameplate.MainModel",
+            "Nameplate.PkgRev",
+            "GridGuard.Cntry.FrqCtl.lLimTmms",
+            "Nameplate.CmpMdul.SwRev",
+            "Nameplate.CmpFltASw.HwRev",
+            "GridGuard.Cntry.Aid.AngFact",
+            "DcCfg.MPPShdw.CycTms",
+            "Nameplate.CmpRS485.Rev",
+            "GridGuard.Cntry",
+            "Operation.ValRsIstl",
+            "Nameplate.SerNum",
+            "GridGuard.Cntry.AMaxOfs",
+            "GridGuard.Cntry.LeakRisMin",
+            "Nameplate.CmpBt.SwRev",
+            "GridGuard.Cntry.GriFltTms",
+            "Metering.TotOpTmhSet",
+            "GridGuard.Cntry.FrqCtl.hLim",
+            "GridGuard.Cntry.FrqCtl.Max",
+            "GridGuard.Cntry.GriStrTms",
+            "Nameplate.CmpCom.SwRev",
+            "GridGuard.Cntry.VolCtl.MaxTmms",
+            "Inverter.StopTms",
+            "Nameplate.CmpCom.HwRev",
+            "Inverter.OffGri.HzdStr",
+            "Nameplate.CmpMain.Rev",
+            "GridGuard.Cntry.VolCtl.lLim",
+            "Nameplate.CmpBt.Rev",
+            "GridGuard.Cntry.GriFltReConTms",
+            "GridGuard.Cntry.VolCtl.llLimTmms",
+            "GridGuard.Cntry.VolCtl.hhLimTmms",
+            "GridGuard.Cntry.FrqCtl.MaxTmms",
+            "Nameplate.CmpDisp.Rev",
+            "Nameplate.CmpDisp.SwRev",
+            "Nameplate.CmpMdul.HwRev",
+            "Nameplate.CmpSigProc.SwRev",
+            "Inverter.WMax",
+            "GridGuard.Cntry.FrqCtl.Min",
+            "DcCfg.StrVol[]",
+            "GridGuard.Cntry.FrqCtl.lLim",
+            "Nameplate.ComRev",
+            "Nameplate.CmpDisp.SerNum",
+            "Nameplate.Vendor",
+            "DcCfg.ConstVolCtl.Vset[]",
+            "GridGuard.Cntry.VolCtl.hLim",
+            "Nameplate.CmpFltASw.SwRev",
+            "GridGuard.Cntry.GriFltMonTms",
+            "GridGuard.Cntry.FrqCtl.MinTmms",
+            "Operation.LodFnc",
+        ],
+    ),
+    (
+        [19143],  # EC22-3AC-20
+        [
+            "Acs.AuthRegistStt",
+            "ChaSess.WhIn",
+            "Chrg.ModSw",
+            "GridMs.A.phsA",
+            "GridMs.A.phsB",
+            "GridMs.A.phsC",
+            "GridMs.PhV.phsA",
+            "GridMs.PhV.phsB",
+            "GridMs.PhV.phsC",
+            "GridMs.TotVA",
+            "GridMs.TotVAr",
+            "GridMs.VA.phsA",
+            "GridMs.VA.phsB",
+            "GridMs.VA.phsC",
+            "GridMs.VAr.phsA",
+            "GridMs.VAr.phsB",
+            "GridMs.VAr.phsC",
+            "GridMs.W.phsA",
+            "GridMs.W.phsB",
+            "GridMs.W.phsC",
+            "InOut.GI1",  # codespell:ignore
+            "InOut.GO1",  # codespell:ignore
+            "Metering.GridMs.TotWIn.ChaSta",
+            "Metering.GridMs.TotWhIn.ChaSta",
+            "Operation.EVeh.ChaStt",
+            "Operation.EVeh.Health",
+            "Operation.Evt.Dsc",
+            "Operation.Evt.EvtNo",
+            "Operation.Evt.Msg",
+            "Operation.EvtCntIstl",
+            "Operation.EvtCntUsr",
+            "Operation.Health",
+            "Operation.WMaxLimSrc",
+            "Spdwr.ComSocA.Stt",
+            "Upd.Stt",
+            "WebConn.Stt",
+            "Wl.AcqStt",
+            "Wl.AntMod",
+            "Wl.ConnStt",
+            "Wl.SigPwr",
+            "Wl.SoftAcsConnStt",
+            "Setpoint.PlantControl.PCC.ChrgActCnt",
+            "Nameplate.Model",
+            "Nameplate.CmpMain.SusyId",
+            "Wl.DoWPS",
+            "Chrg.Plan.En",
+            "WebConn.SwRev",
+            "Nameplate.MainModel",
+            "PCC.ARtg",
+            "Wl.Sec.Psk",
+            "Spdwr.AutoCfgIsOn",
+            "Acs.PwdIstl",
+            "SwCmp.CmpComBlt.SwRev",
+            "Sys.AmbLghtBri",
+            "Nameplate.SerNum",
+            "Spdwr.ActlSnetMsk",
+            "Upd.AutoUpdIsOn",
+            "Nameplate.ChrgCtrl.SusyId",
+            "Inverter.AcALim",
+            "Wl.ActlIp",
+            "Nameplate.CmpCom.HwVer",
+            "Wl.ActlSnetMsk",
+            "Chrg.ActChaMod",
+            "Sys.UseAmbLght",
+            "Acs.PwdUsr",
+            "Spdwr.ActlIp",
+            "Chrg.Plan.StopTm",
+            "Nameplate.CmpOS.SwRev",
+            "Inverter.WMaxIn",
+            "WebConn.IsOn",
+            "PCC.WMaxAsym",
+            "Nameplate.ARtg",
+            "DtTm.NtpSrv",
+            "Inverter.WMax",
+            "Nameplate.ChrgCtrl.SerNumTxt",
+            "Chrg.Plan.DurTmm",
+            "Chrg.ChrgLok",
+            "Nameplate.CmpCom.SerNum",
+            "Wl.ActlDnsSrvIp",
+            "Nameplate.MacId",
+            "Nameplate.ChrgCtrl.SwRevTxt",
+            "Wl.Sec.Cry",
+            "Spdwr.IgmpQryTms",
+            "Nameplate.CmpCom.Rev",
+            "DevUpd.IsOn",
+            "Nameplate.Location",
+            "Spdwr.ActlDnsSrvIp",
+            "Chrg.AMinCha",
+            "Inverter.OutPhs",
+            "Nameplate.PkgRev",
+            "Wl.ActlGwIp",
+            "PCC.FlbInv.WMax",
+            "IecCfg.GoCfg.GoAppId",
+            "Inverter.WMaxInRtg",
+            "Mb.TcpSrv.IsOn",
+            "Sys.DevSigBri",
+            "SwCmp.CmpEnnexOS.Frwk.SwRev",
+            "Nameplate.ChrgCtrl.ChrgTypTxt",
+            "Chrg.CblLok",
+            "Mb.ScdInEna",
+            "Nameplate.ModelStr",
+            "Spdwr.IgmpQryTx",
+            "Spdwr.ActlGwIp",
+            "Chrg.UseEnergyMeter",
+            "Sys.DevRstr",
+            "GridGuard.Cntry.VRtg",
+            "Operation.ComTmOut",
+            "Wl.Sec.Ssid",
+            "Chrg.ChrgApv",
+            "IecCfg.GoCfg.GoMacId",
+            "Nameplate.WlMacId",
+            "Upd.AvalChkIstl",
+            "Nameplate.Vendor",
+            "Wl.IsOn",
+            "Nameplate.VendorStr",
+            "Chrg.StpWhenFl",
+            "Wl.AutoCfgIsOn",
+            "Wl.SoftAcsIsOn",
+            "Chrg.StpWhenFlTm",
+            "Wl.DoAcq",
+            "Sys.DevSig",
+            "Mb.TcpSrv.Port",
+        ],
+    ),
+    (
+        [-47114711],  # Fake Number for Plants
         [
             "GridGuard.Cntry.FrqCtl.ReconMax",
             "GridGuard.Cntry.FrqCtl.ReconMin",
@@ -811,17 +1387,21 @@ ennexosSensorProfiles: list[tuple[list[int], list[str]]] = [
 # fmt: off
 # black -C -l 200 pysma/definitions_ennexos.py
 enneoxSensors = [
-        Sensor("Bat.Amp.1", None, factor=1, unit=None),
-        Sensor("Bat.ChaSttArr.1", None, factor=1, unit=None),
+        Sensor("Bat.Amp.1", Identifier.battery_current_a, factor=1, unit='A'),
+        Sensor("Bat.ChaStt", Identifier.battery_soc_total, factor=1, unit='%'),
+        Sensor("Bat.ChaSttArr.1", Identifier.battery_soc_a, factor=1, unit='%'),
+        Sensor("Bat.TmpVal.1", Identifier.battery_temp_a, factor=1, unit="°C"),
         Sensor("BatChrg.BatChrgArr.1", None, factor=1, unit=None),
         Sensor("BatChrg.BatChrg", None, factor=1, unit=None),
-        Sensor("BatChrg.CurBatChaArr.1", None, factor=1, unit=None),
+        Sensor("BatChrg.CurBatCha", Identifier.battery_power_charge_total, factor=1, unit="W"),
+        Sensor("BatChrg.CurBatChaArr.1", Identifier.battery_power_charge_a, factor=1, unit="W"),
         Sensor("Bat.Diag.VolMax.1", None, factor=1, unit=None),
         Sensor("BatDsch.BatDschArr.1", None, factor=1, unit=None),
         Sensor("BatDsch.BatDsch", None, factor=1, unit=None),
-        Sensor("BatDsch.CurBatDschArr.1", None, factor=1, unit=None),
+        Sensor("BatDsch.CurBatDsch", Identifier.battery_power_discharge_total, factor=1, unit="W"),
+        Sensor("BatDsch.CurBatDschArr.1", Identifier.battery_power_discharge_a, factor=1, unit="W"),
         Sensor("Bat.OpTms.1", None, factor=1, unit=None),
-        Sensor("Bat.Vol.1", None, factor=1, unit=None),
+        Sensor("Bat.Vol.1", Identifier.battery_voltage_a, factor=1, unit="V"),
         Sensor("ChaSess.WhIn", None, factor=1, unit=None),
         Sensor("Chrg.ModSw", None, factor=1, unit=None, mapper=SMATagList),
         Sensor("Coolsys.Inverter.TmpVal.1", Identifier.temp_a, factor=1, unit="°C"),
@@ -830,10 +1410,9 @@ enneoxSensors = [
         Sensor("DcMs.Amp.1", Identifier.pv_current_a, factor=1, unit="A"),
         Sensor("DcMs.Amp.2", Identifier.pv_current_b, factor=1, unit="A"),
         Sensor("DcMs.Amp.3", Identifier.pv_current_c, factor=1, unit="A"),
-        Sensor("DcMs.TotDcEnCntWh.1", None),
-        Sensor("DcMs.TotDcEnCntWh.1", None, factor=1, unit=None),
-        Sensor("DcMs.TotDcEnCntWh.2", None, factor=1, unit=None),
-        Sensor("DcMs.TotDcEnCntWh.3", None, factor=1, unit=None),
+        Sensor("DcMs.TotDcEnCntWh.1", Identifier.pv_total_power_a, factor=1000, unit="kWh"),
+        Sensor("DcMs.TotDcEnCntWh.2", Identifier.pv_total_power_b, factor=1000, unit="kWh"),
+        Sensor("DcMs.TotDcEnCntWh.3", Identifier.pv_total_power_c, factor=1000, unit="kWh"),
         Sensor("DcMs.Vol.1", Identifier.pv_voltage_a, factor=1, unit="V"),
         Sensor("DcMs.Vol.2", Identifier.pv_voltage_b, factor=1, unit="V"),
         Sensor("DcMs.Vol.3", Identifier.pv_voltage_c, factor=1, unit="V"),
@@ -896,13 +1475,13 @@ enneoxSensors = [
         Sensor("Metering.GridMs.PhV.phsB", Identifier.voltage_l2, factor=1, unit="V"),
         Sensor("Metering.GridMs.PhV.phsC", Identifier.voltage_l3, factor=1, unit="V"),
         Sensor("Metering.GridMs.TotPF", None, factor=1, unit=None),
-        Sensor("Metering.GridMs.TotWhIn.Bat", None, factor=1, unit=None),
-        Sensor("Metering.GridMs.TotWhIn.ChaSta", None, factor=1, unit=None),
+        Sensor("Metering.GridMs.TotWhIn.Bat", Identifier.battery_charge_total, factor=1000, unit="kWh"),
+        Sensor("Metering.GridMs.TotWhIn.ChaSta", Identifier.charging_station_total_absorbed, factor=1000, unit="kWh"),
         Sensor("Metering.GridMs.TotWhIn", Identifier.metering_total_absorbed, factor=1000, unit="kWh"),
         # Sensor("Metering.GridMs.TotWhIn", Identifier.metering_total_yield, factor=1000, unit="kWh"),
-        Sensor("Metering.GridMs.TotWhOut.Bat", None, factor=1, unit=None),
+        Sensor("Metering.GridMs.TotWhOut.Bat", Identifier.battery_discharge_total, factor=1000, unit="kWh"),
         Sensor("Metering.GridMs.TotWhOut", Identifier.metering_total_consumption, factor=1000, unit="kWh"),
-        Sensor("Metering.GridMs.TotWIn.ChaSta", None, factor=1, unit=None),
+        Sensor("Metering.GridMs.TotWIn.ChaSta", Identifier.charging_station_power_absorbed, factor=1, unit="W"),
         Sensor("Metering.GridMs.TotWIn", Identifier.metering_power_absorbed, factor=1, unit="W"),
         Sensor("Metering.GridMs.TotWOut", Identifier.metering_power_supplied, factor=1, unit="W"),
         Sensor("Metering.GridMs.VA.phsA", Identifier.grid_apparent_power_l1, factor=1, unit="VA"),
@@ -944,7 +1523,6 @@ enneoxSensors = [
         Sensor("Operation.GriSwCnt", None, factor=1, unit=None),
         Sensor("Operation.GriSwStt", Identifier.grid_relay_status, unit=None, mapper=SMATagList),
         Sensor("Operation.Health", Identifier.status, factor=1, unit=None, mapper=SMATagList),
-        Sensor("Operation.Health", None, factor=1, unit=None),
         Sensor("Operation.HealthStt.Alm", None, factor=1, unit=None),
         Sensor("Operation.HealthStt.Ok", None, factor=1, unit=None),
         Sensor("Operation.HealthStt.Wrn", None, factor=1, unit=None),
@@ -984,10 +1562,12 @@ enneoxSensors = [
         Sensor("Wl.ConnStt", None, factor=1, unit=None),
         Sensor("Wl.SigPwr", None, factor=1, unit=None),
         Sensor("Wl.SoftAcsConnStt", None, factor=1, unit=None),
+        Sensor("Operation.Bat.Health.1", Identifier.battery_status_operating_mode, factor=1, mapper=SMATagList),
 
         Sensor("Operation.Dmd.WCtl", Identifier.active_power_limitation, factor=1, unit="W"),
         Sensor("InOut.DigIn.CurWCtlNom", Identifier.power_limit_via_io, factor=1, unit="%"),  # codespell:ignore
-        Sensor("Inverter.WMaxIn", Identifier.power_limit_in, factor=1, unit="W")
+        Sensor("Inverter.WMaxIn", Identifier.power_limit_in, factor=1, unit="W"),
+        Sensor("Metering.DyWhOut", Identifier.daily_yield, factor=1, unit="Wh")
 ]
 # fmt: on
 name2sensor = {i.key: i for i in enneoxSensors}
@@ -1004,6 +1584,7 @@ def getSensorForDevice(productTagId: int) -> tuple[list[Sensor], list[str]] | No
                 if sensor:
                     expected_sensors.append(sensor)
                 else:
+                    # Sensors that have not yet been integrated into pysma
                     unknown.append(sName)
             return (expected_sensors, unknown)
     return None
