@@ -14,14 +14,14 @@ from typing import Any, Dict, Optional
 from aiohttp import ClientSession, ClientTimeout, client_exceptions, hdrs
 
 from .const import SMATagList
-from .const_webconnect import DEFAULT_TIMEOUT
-from .definitions_ennexos import getSensorForDevice
+from .definitions_ennexos import DEFAULT_TIMEOUT, getSensorForDevice
 from .device import Device, DeviceInformation, DiscoveryInformation
 from .exceptions import (
     SmaAuthenticationException,
     SmaConnectionException,
     SmaReadException,
 )
+from .helpers import splitUrl
 from .sensor import Sensor, Sensor_Range, Sensors
 
 _LOGGER = logging.getLogger(__name__)
@@ -68,9 +68,11 @@ class SMAennexos(Device):
             group (str, optional): Username to use during login.
 
         """
-        self._url = url.rstrip("/")
-        if not url.startswith("http"):
-            self._url = "https://" + self._url
+        destination = splitUrl(url, "https")
+        self._url = destination["schema"] + "://" + destination["host"]
+        if destination["port"] is not None:
+            self._url = self._url + ":" + str(destination["port"])
+        _LOGGER.debug(f"Ennexos {url} => {self._url}")
         self._new_session_data = {"user": group, "pass": password}
         self._aio_session = session
 
@@ -95,10 +97,14 @@ class SMAennexos(Device):
             async with self._aio_session.request(
                 method, url, timeout=ClientTimeout(total=DEFAULT_TIMEOUT), **parameters
             ) as res:
+                _LOGGER.debug(f"Request {url} Code {res.status}")
                 if res.status == 200:
-                    res = await res.json()
-                    return res
+                    resjson = await res.json()
+                    return resjson
                 elif res.status == 401 or res.status == 400:
+                    resjson = await res.json()
+                    _LOGGER.error("Error " + str(res.status))
+                    _LOGGER.error(resjson)
                     raise SmaAuthenticationException("Token failed!")
                 else:
                     _LOGGER.warning("HTTP-Error %d for %s", res.status, url)
@@ -106,8 +112,15 @@ class SMAennexos(Device):
         except SmaAuthenticationException as e:
             raise e
         except (client_exceptions.ContentTypeError, json.decoder.JSONDecodeError):
-            _LOGGER.warning("Request to %s did not return a valid json.", url)
+            _LOGGER.error(
+                "Request to %s did not return a valid json. Code %d", url, res.status
+            )
+            if res.status == 401:
+                raise SmaAuthenticationException("Token failed and no json response!")
         except client_exceptions.ServerDisconnectedError as exc:
+            _LOGGER.error(
+                f"Timeout while requesting {url} {exc}. (Probably wrong ip, wrong hostname or wrong setting for http/https)"
+            )
             raise SmaConnectionException(
                 f"Server at {self._url} disconnected."
             ) from exc
@@ -115,8 +128,10 @@ class SMAennexos(Device):
             client_exceptions.ClientError,
             asyncio.exceptions.TimeoutError,
         ) as exc:
+            if "/api/v1/featuretoggles" not in url:
+                _LOGGER.error(f"Error requesting {url} {exc} [Timeout]")
             raise SmaConnectionException(
-                f"Could not connect to SMA at {self._url}: {exc}"
+                f"Could not connect to SMA at {self._url} -- {exc}"
             ) from exc
         return {}
 
@@ -130,6 +145,7 @@ class SMAennexos(Device):
         if self._new_session_data is None:
             _LOGGER.error("User & Pwd not set!")
             return False
+        _LOGGER.debug(f'Trying to login {self._url} {self._new_session_data["user"]}')
         loginurl = self._url + "/api/v1/token"
         postdata = {
             "data": {
@@ -140,6 +156,7 @@ class SMAennexos(Device):
         }
         ret = await self._jsonrequest(loginurl, postdata)
         if "access_token" not in ret:
+            _LOGGER.debug(f"Login failed {ret}")
             raise SmaAuthenticationException("Login failed!")
         self._authorization_header = {
             "Authorization": "Bearer " + ret["access_token"],
@@ -153,9 +170,15 @@ class SMAennexos(Device):
             "/api/v1/featuretoggles",
         ]:
             url = self._url + u
-            ret = await self._jsonrequest(
-                url, {"headers": self._authorization_header}, hdrs.METH_GET
-            )
+            try:
+                ret = await self._jsonrequest(
+                    url, {"headers": self._authorization_header}, hdrs.METH_GET
+                )
+            except SmaConnectionException as e:
+                # Ignore Error while requesting featuretoogles as not available on all systems
+                if u == "/api/v1/featuretoggles":
+                    continue
+                raise e
             if isinstance(ret, dict):
                 ret.pop("_links", None)
             if isinstance(ret, list):
@@ -308,8 +331,8 @@ class SMAennexos(Device):
         productTagId = int(dev.additional.get("productTagId", 0))
         profile = getSensorForDevice(productTagId)
         if not profile:
-            _LOGGER.warning(
-                f"Unknown Device: {productTagId} N:{dev.name} T:{dev.type} ID:{deviceID}"
+            _LOGGER.error(
+                f"Unknown Device: {productTagId} N:{dev.name} T:{dev.type} ID:{deviceID}. Please report to the author of pysmaplus."
             )
             return device_sensors
         expected_sensors, unknown = profile
@@ -457,7 +480,7 @@ class SMAennexos(Device):
             devInfo["product"],
             devInfo["name"],
             devInfo["vendor"],
-            devInfo["firmwareVersion"],
+            devInfo.get("firmwareVersion", "0.0"),
         )
         para = await self._get_parameter(componentId)
         di.parameterCount = len(para)
@@ -537,6 +560,7 @@ class SMAennexos(Device):
         timestamp = await self._get_timestamp()
         parameters = await self._get_parameter(deviceID)
         channelName = parameters[sensor.key]["origname"]
+        # T.O.D.O Validation of the value
         requestData = f'{{"values":[{{"channelId":"{channelName}","timestamp":"{timestamp}","value":"{value}"}}]}}'
         putdata = {
             "data": requestData,
