@@ -14,6 +14,7 @@ import logging
 import struct
 import time
 from asyncio import DatagramProtocol, Future
+from datetime import datetime, timedelta
 from typing import Any, Dict, List, Optional
 
 from .const import SMATagList
@@ -35,6 +36,10 @@ from .sensor import Sensor, Sensors
 
 _LOGGER = logging.getLogger(__name__)
 
+NO_HANDLER_FOR_MIN_TIMEDELTA = timedelta(
+    hours=24
+)  # How often to report a "known unknown" response
+
 
 class SMAClientProtocol(DatagramProtocol):
     """Basic Class for communication"""
@@ -49,6 +54,8 @@ class SMAClientProtocol(DatagramProtocol):
         "sendcounter": 0,
         "resendcounter": 0,
         "failedCounter": 0,
+        "warned": {},  # dictionary of "No handler for" addresses with timestamp of last logged message,
+        # so it can be repeated daily (instead of per poll)
     }
 
     def __init__(
@@ -67,16 +74,25 @@ class SMAClientProtocol(DatagramProtocol):
         self.sensors: dict[str, Sensor] = {}
         self._group = ""
         self._resendcounter = 0
+        self._defaultRetries = int(options.get("defaultRetries", 2))
+        self._loginRetries = int(options.get("loginRetries", 3))
+        self._loggedIn = False
         self._failedCounter = 0
         self._sendCounter = 0
         self._commandTimeout = float(options.get("commandTimeout", 0.5))
         self._commandDelay = float(options.get("commandDelay", 0.0))
+        self._overallTimeout = max(
+            5 + len(commands) * (self._commandDelay) * 2,
+            (self._commandTimeout + self._commandDelay)
+            * (max(self._loginRetries, self._loginRetries) + 1),
+        )
         self._overallTimeout = float(
-            options.get("overallTimeout", 5 + len(commands) * (self._commandDelay))
+            options.get("overallTimeout", self._overallTimeout)
         )
         self.allCmds: list[str] = []
         self.allCmds.extend(commands.keys())
         self.allCmds.remove("login")
+        self.allCmds.remove("login2")
         self.allCmds.remove("logoff")
 
     def connection_made(self, transport: Any) -> None:
@@ -96,8 +112,18 @@ class SMAClientProtocol(DatagramProtocol):
             _LOGGER.debug(f"Timeout in command. Resendcounter: {self._resendcounter}")
             self._resendcounter += 1
             self.debug["resendcounter"] += 1
-            if self._resendcounter > 2:
+            retries = self._defaultRetries
+            if self.cmds[self.cmdidx] == "login":
+                retries = self._loginRetries
+            _LOGGER.debug(
+                f"Timeout in command. Resendcounter: {self._resendcounter} {retries}"
+            )
+            if self._resendcounter > retries:
                 # Giving up. Next Command
+                if self.cmds[self.cmdidx] == "login" and not self.future.done():
+                    self.future.set_exception(
+                        SmaConnectionException("Login failed! No Response from Device!")
+                    )
                 _LOGGER.debug("Timeout in command")
                 self.cmdidx += 1
                 self._resendcounter = 0
@@ -113,7 +139,9 @@ class SMAClientProtocol(DatagramProtocol):
         self._commandFuture.set_result(True)
 
     async def start_query(self, cmds: List, future: Future, group: str) -> None:
-        self.cmds = ["login"]
+        self.cmds = []
+        if not self._loggedIn:
+            self.cmds.append("login")
         self.cmds.extend(cmds)
         self.future = future
         self.cmdidx = 0
@@ -122,7 +150,8 @@ class SMAClientProtocol(DatagramProtocol):
         self._group = group
         self.data_values = {}
         self.sensors = {}
-        _LOGGER.debug("Sending login")
+        _LOGGER.debug(f"Start Query {cmds}")
+        #        _LOGGER.debug("Sending login")
         self.debug["msg"].append(["SEND", "login"])
         self._firstSend = time.time()
         await self._send_next_command()
@@ -130,32 +159,44 @@ class SMAClientProtocol(DatagramProtocol):
     def connection_lost(self, exc: Exception | None) -> None:
         """connection lost handler"""
         _LOGGER.debug("Connection lost: %s %s", type(exc), exc)
+        self._loggedIn = False
         self.on_connection_lost.set_result(True)
 
-    def _send_command(self, cmd: bytes) -> None:
+    def _send_command(self, cmd: bytes, exceptResponse: bool = True) -> None:
         """Send the Command"""
         _LOGGER.debug(
             f"Sending command [{len(cmd)}] -- {binascii.hexlify(cmd).upper()}"  # type: ignore[str-bytes-safe]
         )
-        self._commandFuture = asyncio.get_running_loop().create_future()
-        asyncio.get_running_loop().create_task(self.controller())
+        if exceptResponse:
+            self._commandFuture = asyncio.get_running_loop().create_future()
+            asyncio.get_running_loop().create_task(self.controller())
         if self._transport is None:
             raise RuntimeError("Transport is None")
         self._transport.sendto(cmd)
 
+    async def logoff(self) -> None:
+        _LOGGER.debug("Sending logoff")
+        try:
+            self._send_command(self.speedwire.getLogoutFrame(0x23021923), False)
+            await asyncio.sleep(0.2)  # Wait for delayed responses
+            self._loggedIn = False
+        except RuntimeError:
+            pass
+
     async def _send_next_command(self) -> None:
         """Send the next command in the list"""
         if not self.future:
             return
         if self.cmdidx >= len(self.cmds):
-            # All commands send. Clean up.
+            await self.logoff()
             f = self.future
             self.future = None
             await asyncio.sleep(0.2)  # Wait for delayed responses
             self.debug["data"] = self.data_values
             self.cmds = []
             self.cmdidx = 0
-            f.set_result(True)
+            if not f.done():
+                f.set_result(True)
             if self._firstSend:
                 self.debug["msg"].append(
                     ["TOTAL", 0, "", round(time.time() - self._firstSend, 2)]
@@ -172,13 +213,11 @@ class SMAClientProtocol(DatagramProtocol):
             if (self.cmds[self.cmdidx]) == "login":
                 groupidx = ["user", "installer"].index(self._group) == 1
                 self._send_command(
-                    self.speedwire.getLoginFrame(self.password, 0, groupidx)
+                    self.speedwire.getLoginFrame(self.password, 0x23021923, groupidx)
                 )
             else:
                 self._send_command(
-                    self.speedwire.getQueryFrame(
-                        self.password, 0, self.cmds[self.cmdidx]
-                    )
+                    self.speedwire.getQueryFrame(0x23021923, self.cmds[self.cmdidx])
                 )
 
     def _getFormat(self, handler: dict) -> tuple:
@@ -211,6 +250,8 @@ class SMAClientProtocol(DatagramProtocol):
                         "Login failed! Credentials wrong (user/install or password)"
                     )
                 )
+        else:
+            self._loggedIn = True
 
     def handle_newvalue(self, sensor: Sensor, value: Any, overwrite: bool) -> None:
         """Set the new value to the sensor"""
@@ -274,8 +315,20 @@ class SMAClientProtocol(DatagramProtocol):
                 v = struct.unpack("<l", subdata[idx : idx + 4])[0]
                 values.append(v)
                 valuesPos.append(f"{idx + 54}")
-            _LOGGER.warning(f"No Handler for {c}: {values} @ {valuesPos}")
+            # check if the value 'c' was already logged within the last 24 hrs (TIMEDELTA def above)
+
+            if (ts := self.debug.get("warned", {}).get(c)) and ts > (
+                datetime.now() - NO_HANDLER_FOR_MIN_TIMEDELTA
+            ):
+                # do not warn again
+                # it also already known to "unfinished" set
+                return
+
+            _LOGGER.debug(f"No Handler for {c}: {values} @ {valuesPos}")
             self.debug["unfinished"].add(f"{c}")
+            self.debug["warned"][
+                c
+            ] = datetime.now()  # add to known unknowns that have been warned
             return
 
         # Handle known repsones
@@ -388,7 +441,7 @@ class SMAspeedwireINV(Device):
 
     _options: Dict[str, Any] = {}
     _transport = None
-    _protocol: SMAClientProtocol
+    _protocol = None
     _deviceinfo: DeviceInformation
     _debug: Dict[str, Any] = {"overalltimeout": 0}
 
@@ -400,10 +453,15 @@ class SMAspeedwireINV(Device):
             raise KeyError(f"Invalid user type: {group} (user or installer)")
 
     async def _createEndpoint(self) -> None:
+        if self._protocol is not None:
+            # _LOGGER.debug("Protocol already created")
+            return
         loop = asyncio.get_running_loop()
         on_connection_lost = loop.create_future()
         if not self._password:
             raise ValueError("Password not set!")
+        if len(self._password) > 12:
+            raise ValueError("Password to long! Max 12 Characters.")
         self._transport, self._protocol = await loop.create_datagram_endpoint(
             lambda: SMAClientProtocol(
                 self._password,  # type: ignore[arg-type]
@@ -417,11 +475,17 @@ class SMAspeedwireINV(Device):
     async def new_session(self) -> bool:
         # Create Endpoint
         await self._createEndpoint()
+        if self._protocol is None:
+            raise SmaConnectionException("protocol not initialized")
 
+        self._protocol._failedCounter = 0
+        self._protocol._sendCounter = 0
         # Test with device_info if the ip and user/pwd are correct
         await self.device_info()
         if self._protocol._failedCounter >= self._protocol._sendCounter:
-            raise SmaConnectionException("No connection to device: %s:9522", self._host)
+            raise SmaConnectionException(
+                f"No connection to device: {self._host}:9522  ({self._protocol._failedCounter}/{self._protocol._sendCounter})"
+            )
         return True
 
     # @override
@@ -431,6 +495,8 @@ class SMAspeedwireINV(Device):
 
     # @override
     async def device_list(self) -> dict[str, DeviceInformation]:
+        if self._protocol is None:
+            raise SmaConnectionException("protocol not initialized")
 
         fut = asyncio.get_running_loop().create_future()
         await self._protocol.start_query(["TypeLabel", "Firmware"], fut, self._group)
@@ -467,6 +533,9 @@ class SMAspeedwireINV(Device):
 
     # @override
     async def get_sensors(self, deviceID: str | None = None) -> Sensors:
+        if self._protocol is None:
+            raise SmaConnectionException("protocol not initialized")
+
         fut = asyncio.get_running_loop().create_future()
         c = self._protocol.allCmds
         device_sensors = Sensors()
@@ -482,6 +551,9 @@ class SMAspeedwireINV(Device):
 
     # @override
     async def read(self, sensors: Sensors, deviceID: str | None = None) -> bool:
+        if self._protocol is None:
+            raise SmaConnectionException("protocol not initialized")
+
         fut = asyncio.get_running_loop().create_future()
         c = self._protocol.allCmds
         await self._protocol.start_query(c, fut, self._group)
@@ -507,9 +579,14 @@ class SMAspeedwireINV(Device):
 
     async def close_session(self) -> None:
         if self._transport is not None:
+            await self._protocol.logoff()
             self._transport.close()
+            self._trasport = None
 
     async def get_debug(self) -> Dict:
+        if self._protocol is None:
+            raise SmaConnectionException("protocol not initialized")
+
         ret = self._protocol.debug.copy()
         ret["unfinished"] = list(ret["unfinished"])
         ret["msg"] = list(ret["msg"])
@@ -520,10 +597,12 @@ class SMAspeedwireINV(Device):
 
     # wait for a response or a timeout
     async def detect(self, ip: str) -> list[DiscoveryInformation]:
+        di = DiscoveryInformation()
+        di.tested_endpoints = str(ip) + ":9522"
         try:
-            di = DiscoveryInformation()
-            di.tested_endpoints = str(ip) + ":9522"
             await self.new_session()
+            if self._protocol is None:
+                raise SmaConnectionException("protocol not initialized")
             fut = asyncio.get_running_loop().create_future()
             await self._protocol.start_query(["TypeLabel"], fut, self._group)
             try:
