@@ -31,6 +31,7 @@ from .const_webconnect import (
     URL_LOGGER,
     URL_LOGIN,
     URL_LOGOUT,
+    URL_SETPARAMETER,
     URL_VALUES,
     USERS,
 )
@@ -41,7 +42,7 @@ from .exceptions import (
     SmaReadException,
 )
 from .helpers import version_int_to_string
-from .sensor import Sensors
+from .sensor import Sensor, Sensors
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -53,6 +54,8 @@ class Debug_information_webconnect:
     full_json: dict | None = None
     last_json: dict | None = None
     device_info: DeviceInformation | None = None
+    all_values: dict | None = None
+    all_params: dict | None = None
 
 
 class SMAwebconnect(Device):
@@ -154,7 +157,7 @@ class SMAwebconnect(Device):
                 if (retry + 1) < max_retries:
                     # For some reason the SMA device sometimes raises a server disconnected error
                     # If this happens we will retry up to `max_retries` times
-                    # This prevents errors in Home Assistant
+                    # This  events errors in Home Assistant
                     _LOGGER.debug("ServerDisconnectedError, will retry connection.")
                     continue
 
@@ -419,6 +422,8 @@ class SMAwebconnect(Device):
     async def _read_all_sensors(self) -> dict:
         all_values = await self._read_body(URL_ALL_VALUES, {"destDev": []})
         all_params = await self._read_body(URL_ALL_PARAMS, {"destDev": []})
+        self._debug.all_values = all_values
+        self._debug.all_params = all_params
         return all_values | all_params
 
     # @override
@@ -529,3 +534,24 @@ class SMAwebconnect(Device):
                 di.exception = e
             results.append(di)
         return results
+
+    # @override
+    async def set_parameter(
+        self, sensor: Sensor, value: int, deviceID: str | None = None
+    ) -> None:
+        """Set Parameters."""
+        if sensor.webconnect_deviceId is None:
+            _LOGGER.info(
+                f"Cannot set Parameter {sensor} {value} {deviceID}. Device ID could not be determined."
+            )
+            return
+
+        key = sensor.key
+        requestData = {
+            "destDev": [],
+            "values": [{str(key): {sensor.webconnect_deviceId: [value]}}],
+        }
+        ret = await self._post_json(URL_SETPARAMETER, requestData)
+        _LOGGER.info(
+            f"Set_Paramter {sensor} {value} {deviceID} {sensor.webconnect_deviceId} Return {ret}"
+        )
